SequencerLayout4

Struct SequencerLayout4 

#[repr(C, align(64))]
pub struct SequencerLayout4 { pub header: LayoutHeader, pub initialized: IndexbusAtomicU32, pub pad0: u32, pub pad_to_64: [u8; 40], pub cursor: IndexbusAtomicU64, pub pad_cursor: [u8; 56], pub gating: [SequencerGatingCell; 4], }
Concrete v1 sequencer layout for N=4 (header generation target).

Fields

header: LayoutHeader

Common region header (magic/version/capabilities/layout size).

initialized: IndexbusAtomicU32

0 = uninitialized, 1 = initializing, 2 = initialized

pad0: u32

Padding (reserved).

pad_to_64: [u8; 40]

Pad to 64 so the first counter starts at offset 64.

cursor: IndexbusAtomicU64

Producer cursor (monotonic sequence).

pad_cursor: [u8; 56]

Padding to keep the cursor in its own cache line.

gating: [SequencerGatingCell; 4]

Per-consumer gating sequences.

Implementations

Source

impl SequencerLayout4

pub const REQUIRED_CAPS: u32 = caps::INDEXBUS_CAP_SUPPORTS_SEQUENCER

Capabilities required for this region to be considered compatible.