BlockingFanoutRouter

Struct BlockingFanoutRouter 

pub struct BlockingFanoutRouter<const N: usize> { /* private fields */ }
Blocking wrapper over an indexbus-core fanout router.

Implementations

Source

impl<const N: usize> BlockingFanoutRouter<N>

pub fn route_once_with_stats( &self, source: RouterSource, mode: RouterMode, ) -> RouteOnceResult

Route once (delegates to indexbus-core) and wake any blocked consumers on delivery.

pub fn as_inner(&self) -> &FanoutRouter<N>

Access the underlying nonblocking router.

pub fn producer_seq(&self) -> u32

Read the current producer wake sequence.

pub fn wait_producer_seq_ne( &self, expected: u32, timeout: Option<Duration>, ) -> Result<bool>

Wait until the producer sequence differs from expected or timeout.

Returns:

  • Ok(true) if woken due to a change
  • Ok(false) on timeout
pub fn wait_consumer_seq_ne( &self, consumer: usize, expected: u32, timeout: Option<Duration>, ) -> Result<bool>

Wait until the consumer wake sequence differs from expected or timeout.

pub fn consumer_seq(&self, consumer: usize) -> Option<u32>

Read the current consumer wake sequence for consumer.