BlockingFanoutRouterRef

Struct BlockingFanoutRouterRef 

pub struct BlockingFanoutRouterRef<'a, const N: usize> { /* private fields */ }
Blocking view over an existing FanoutRouter reference.

Implementations

Source

impl<const N: usize> BlockingFanoutRouterRef<'_, N>

pub fn route_once_with_stats( &self, source: RouterSource, mode: RouterMode, ) -> RouteOnceResult

Route once (delegates to indexbus-core) and wake any blocked consumers on delivery.

pub fn producer_seq(&self) -> u32

Read the current producer wake sequence.

pub fn consumer_seq(&self, consumer: usize) -> Option<u32>

Read the current consumer wake sequence for consumer.

pub fn wait_producer_seq_ne( &self, expected: u32, timeout: Option<Duration>, ) -> Result<bool>

Wait until the producer wake sequence differs from expected or timeout.

pub fn wait_consumer_seq_ne( &self, consumer: usize, expected: u32, timeout: Option<Duration>, ) -> Result<bool>

Wait until the consumer wake sequence differs from expected or timeout.