pub fn cpu_relax()Expand description
Hint to the processor that we are in a spin-wait loop.
This is a thin wrapper over core::hint::spin_loop().
pub fn cpu_relax()Hint to the processor that we are in a spin-wait loop.
This is a thin wrapper over core::hint::spin_loop().