init_shared_layout_with_layout_bytes

Function init_shared_layout_with_layout_bytes 

pub fn init_shared_layout_with_layout_bytes(
    shared: &mut SharedLayout,
    capabilities: u32,
    layout_bytes: u32,
)
Initialize a shared events layout in-place.

Safe because &mut guarantees exclusive access.

layout_bytes should reflect the total mapped byte length of the region. If capabilities includes INDEXBUS_CAP_SUPPORTS_BLOCKING, the mapping is expected to include an appended wake section at the next 64B boundary (see validate_shared_layout).