split_chain_spsc

Function split_chain_spsc 

pub unsafe fn split_chain_spsc(
    pool: *mut SlotPoolLayout,
    queue: *mut IndexQueue,
) -> (ChainSpscSender, ChainSpscReceiver)
Create SPSC sender/receiver handles over a shared slot pool and a specific queue.

Safety

The caller must ensure:

  • pool and queue point into a valid, initialized, mapped region.
  • The mapping outlives all returned handles.
  • Exactly one thread uses the sender at a time, and exactly one thread uses the receiver.