StateLayoutCell

Struct StateLayoutCell 

pub struct StateLayoutCell<const STATE_MAX: usize>(/* private fields */);
StateLayout wrapper that explicitly opts into interior mutability.

The v1 state layout is designed for concurrent mutation through atomics and raw pointers. Rust requires such mutation through a shared reference to be mediated by UnsafeCell.

Implementations

Source

impl<const STATE_MAX: usize> StateLayoutCell<STATE_MAX>

pub fn from_mut( inner: &mut StateLayout<STATE_MAX>, ) -> &StateLayoutCell<STATE_MAX>

Borrow a StateLayoutCell view over a uniquely-mutable StateLayout.

pub unsafe fn from_ptr<'a>( ptr: *mut StateLayout<STATE_MAX>, ) -> &'a StateLayoutCell<STATE_MAX>

Borrow a StateLayoutCell view over a raw pointer.

Safety

ptr must be valid for reads/writes for the lifetime 'a.