FanoutConsumer

Struct FanoutConsumer 

pub struct FanoutConsumer<const N: usize> { /* private fields */ }
Consumer handle for a fanout events region.

Consumers only receive messages after they have been routed into their consumer queue. Without a running router, consumers will not observe new messages.

Implementations

Source

impl<const N: usize> FanoutConsumer<N>

pub fn try_recv_into(&self, out: &mut [u8]) -> Result<Option<usize>, Error>

Attempt to receive the next message into out.

Returns:

  • Ok(Some(n)) when a message of length n was copied into out
  • Ok(None) when empty (or if consumer is out of range)
  • Err(Error::BufferTooSmall) when out cannot hold the message
pub fn try_recv_with<F, R, E>( &self, f: F, ) -> Result<Option<R>, RecvWithError<E>>
where F: FnOnce(&[u8]) -> Result<R, E>,

Receive by borrowing the slot bytes for the duration of f.

The borrowed &[u8] is only valid for the duration of the callback.

If the callback returns Err, the message is still considered consumed; it will not be re-delivered.