RouteOnceResult

Struct RouteOnceResult 

pub struct RouteOnceResult {
    pub routed: bool,
    pub delivered: u32,
    pub dropped: u32,
}
Result of a single FanoutRouter routing step.

Fields

routed: bool

Whether a message was dequeued from the selected source queue.

delivered: u32

Number of consumer queues the message was enqueued into.

dropped: u32

Number of enqueue failures (typically due to full consumer queues).

Note: In RouterMode::Broadcast, a single message can be dropped for some consumers but still delivered to others.