static_spsc

Function static_spsc 

pub fn static_spsc() -> Result<(SpscSender, SpscReceiver)>
Create an SPSC sender/receiver backed by a statically allocated SharedLayout.

Notes:

  • This is intended for embedded-ish demonstrations and algorithmic reuse.
  • This is single-use: it hands out handles into a single static region.
  • Calling this more than once returns an error (to avoid re-initialization while old handles may still exist).