pub struct ReadinessGate { /* private fields */ }Expand description
Aggregates multiple components into a single readiness latch.
The gate becomes “ready” once required components have called component_started().
Implementations
Sourceimpl ReadinessGate
impl ReadinessGate
Sourcepub fn with_on_ready(
self,
on_ready: Arc<dyn Fn() + Send + Sync + 'static>,
) -> Self
pub fn with_on_ready( self, on_ready: Arc<dyn Fn() + Send + Sync + 'static>, ) -> Self
Install an on_ready callback invoked once when the gate becomes ready.
Sourcepub fn token(self: &Arc<Self>) -> ReadinessToken
pub fn token(self: &Arc<Self>) -> ReadinessToken
Produce a token to be handed to a component/thread.