pub fn typed_fanout_consumer<const N: usize>(
cons: FanoutConsumer<N>,
) -> TypedFanoutConsumer<N, RawTypedCodec>Expand description
Wrap a fanout consumer with typed messaging using the raw codec.
pub fn typed_fanout_consumer<const N: usize>(
cons: FanoutConsumer<N>,
) -> TypedFanoutConsumer<N, RawTypedCodec>Wrap a fanout consumer with typed messaging using the raw codec.