pub fn typed_fanout_producer<const N: usize>(
prod: FanoutProducer<N>,
) -> TypedFanoutProducer<N, RawTypedCodec>Expand description
Wrap a fanout producer with typed messaging using the raw codec.
pub fn typed_fanout_producer<const N: usize>(
prod: FanoutProducer<N>,
) -> TypedFanoutProducer<N, RawTypedCodec>Wrap a fanout producer with typed messaging using the raw codec.