CodecKit

Struct CodecKit 

pub struct CodecKit<C> {
    pub codec: C,
}
Generic typed-codec “kit” that builds typed producers/consumers for any codec.

The kit is intentionally tiny: it mostly provides constructors and a couple of ergonomic helpers. The underlying typed wrappers (indexbus-typed) are the source of truth.

Fields

codec: C

The codec instance used by the typed wrappers created by this kit.

Implementations

Source

impl<C> CodecKit<C>

pub const fn new(codec: C) -> Self

Create a new codec kit from a codec instance.

Source

impl<C: Copy> CodecKit<C>

pub fn spsc_sender(self, inner: SpscSender) -> TypedSpscSender<C>

Wrap an SPSC sender with typed messaging.

pub fn spsc_receiver(self, inner: SpscReceiver) -> TypedSpscReceiver<C>

Wrap an SPSC receiver with typed messaging.

pub fn mpsc_producer(self, inner: MpscProducer) -> TypedMpscProducer<C>

Wrap an MPSC producer with typed messaging.

pub fn mpsc_consumer(self, inner: MpscConsumer) -> TypedMpscConsumer<C>

Wrap an MPSC consumer with typed messaging.

pub fn fanout_producer<const N: usize>( self, inner: FanoutProducer<N>, ) -> TypedFanoutProducer<N, C>

Wrap a fanout producer with typed messaging.

pub fn fanout_consumer<const N: usize>( self, inner: FanoutConsumer<N>, ) -> TypedFanoutConsumer<N, C>

Wrap a fanout consumer with typed messaging.

pub fn fanout_mpsc_producer<const N: usize>( self, inner: FanoutMpscProducer<N>, ) -> TypedFanoutMpscProducer<N, C>

Wrap a fanout MPSC producer with typed messaging.