pub struct ShutdownToken { /* private fields */ }Expand description
A clonable shutdown token that tasks can poll or wait on.
Contract: this token is a cooperative cancellation primitive.
Tasks/threads are expected to poll ShutdownToken::is_shutdown and exit promptly when it
becomes true.
Features: waiting APIs require std.
Implementations
Sourceimpl ShutdownToken
impl ShutdownToken
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Returns true iff shutdown has been triggered.
Contract: once true, this will remain true for the lifetime of the token.
Sourcepub fn wait(&self)
pub fn wait(&self)
Block the current thread until shutdown is triggered.
Panics: panics if the internal mutex is poisoned.
Sourcepub fn wait_timeout(&self, timeout: Duration) -> bool
pub fn wait_timeout(&self, timeout: Duration) -> bool
Block the current thread until shutdown is triggered, or the timeout elapses.
Returns true if shutdown was observed.
Panics: panics if the internal mutex is poisoned.