Error

Enum Error 

pub enum Error {
    Io(Error),
    Layout(Error),
    RegionTooSmall {
        needed: usize,
        found: usize,
    },
    Misaligned {
        align: usize,
    },
}
Errors returned by the indexbus-transport-shm adapter.

Variants



Io(Error)

An I/O error occurred while opening, sizing, or mapping the backing file.



Layout(Error)

The mapped bytes do not contain a compatible v1 layout.

This includes magic/version mismatches, missing capability bits (e.g. blocking requested but wake section absent), and uninitialized layouts.



RegionTooSmall

The backing file is smaller than the required bytes for the chosen layout/options.

Fields

needed: usize

Minimum number of bytes required.

found: usize

Number of bytes available in the mapped file.



Misaligned

The mapping base address is not aligned as required for the layout type.

Fields

align: usize

The required byte alignment for the target layout type.