pub struct FanoutRegion<const N: usize> { /* private fields */ }Expand description
File-backed shared fanout region.
See EventsRegion for the creator/joiner initialization model.
Implementations
Sourceimpl<const N: usize> FanoutRegion<N>
impl<const N: usize> FanoutRegion<N>
Sourcepub fn open(name: &str) -> Result<Self, Error>
pub fn open(name: &str) -> Result<Self, Error>
Open (or create) a fanout region using the default path for name.
Sourcepub fn open_with(name: &str, options: OpenOptions) -> Result<Self, Error>
pub fn open_with(name: &str, options: OpenOptions) -> Result<Self, Error>
Open (or create) a fanout region using explicit options.
Sourcepub fn open_path(path: impl AsRef<Path>) -> Result<Self, Error>
pub fn open_path(path: impl AsRef<Path>) -> Result<Self, Error>
Open (or create) a fanout region backed by path.
Sourcepub fn open_path_with(
path: impl AsRef<Path>,
options: OpenOptions,
) -> Result<Self, Error>
pub fn open_path_with( path: impl AsRef<Path>, options: OpenOptions, ) -> Result<Self, Error>
Open (or create) a fanout region backed by path with explicit options.
See EventsRegion::open_path_with for error semantics.