pub struct OpenOptions { /* private fields */ }Expand description
Options for opening a mapped region.
These options must be consistent across all processes that open the same backing file.
For example, if a creator initializes without blocking and a joiner requests blocking,
opening fails with a layout compatibility error.
Implementations
Sourceimpl OpenOptions
impl OpenOptions