SequencerRegion

Struct SequencerRegion 

pub struct SequencerRegion<const N: usize> { /* private fields */ }
File-backed shared sequencer region.

See EventsRegion for the creator/joiner initialization model.

Implementations

Source

impl<const N: usize> SequencerRegion<N>

pub fn open(name: &str) -> Result<Self, Error>

Open (or create) a sequencer region using the default path for name.

pub fn open_with(name: &str, options: OpenOptions) -> Result<Self, Error>

Open (or create) a sequencer region using explicit options.

pub fn open_path(path: impl AsRef<Path>) -> Result<Self, Error>

Open (or create) a sequencer region backed by path.

pub fn open_path_with( path: impl AsRef<Path>, options: OpenOptions, ) -> Result<Self, Error>

Open (or create) a sequencer region backed by path with explicit options.

See EventsRegion::open_path_with for error semantics.

pub fn as_ptr(&self) -> *mut SequencerLayout<N>

Get the raw layout pointer for this mapping.

The pointer is valid as long as the SequencerRegion is alive.

pub fn producer( &self, cfg: SequencerProducerConfig, ) -> Result<SequencerProducer<'_, N>, Error>

Create a sequencer producer with the provided configuration.

pub fn consumer( &self, consumer: usize, ) -> Result<SequencerConsumer<'_, N>, Error>

Create a sequencer consumer for consumer.

pub fn barrier_for_cursor(&self) -> Result<SequencerBarrier<'_, N>, Error>

Create a barrier that tracks the producer cursor.