pub fn spawn_shm_router_with_config<const N: usize>(
path: PathBuf,
cfg: RouterLoopConfig,
options: RouterThreadOptions,
) -> Result<RouterThread>Expand description
Spawn a router thread with the provided loop config and options.
The returned handle contains an internal stop flag which can be triggered via RouterThread::stop.