pub fn mlockall_current_and_future() -> Result<()>Expand description
Attempts to lock current and future mappings into RAM (mlockall).
Linux-only; on other targets returns an error.
Errors
Returns an error if mlockall fails or is not supported on this platform.